<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       http://example.com
 * @since      1.0.0
 *
 * @package    Gdpr_tools
 * @subpackage Gdpr_tools/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Gdpr_tools
 * @subpackage Gdpr_tools/admin
 * @author     Your Name <email@example.com>
 */
class Gdpr_tools_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $gdpr_tools    The ID of this plugin.
	 */
	private $gdpr_tools;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/*
	Save current webpage suffix to load assets
	*/
	private $page_suffix;
	protected $settings;

	private $default_settings = [
		'enable_cookie_notice' => true,
		'notice_position' => 'bottom',
		'notice_accept_button_text' => 'Ok',
		'notice_message' => 'We use cookies. Check <a href="/cookie-policy">our cookie policy</a> to find out more.',
		'notice_theme' => 'dark',
		
		'accept_button_bg_color' => '#0091FF',
		'notice_bg_color' => '#222',
		'accept_button_color' => '#FFF', 
		'message_color' => '#FFF',
		'link_color' => '#FFF',
		'accept_button_color' => '#FFF', 
		'border_color' =>  'transparent', 
		'link_hover_color' => '#55c8ff',
		'enable_privacy_settings' => true,
		'privacy_btn_text' => 'Privacy Settings',
		'custom_css' => '',

		'privacy_services' => [],
		'trigger_privacy_modal_class' => false,
		'privacy_button_color' => '#FFF',
		'privacy_button_bg_color' => '#be1111',

		'enable_user_info_removal' => false,
		'remove_mailchimp_email' => false,
		'mailchimp_api_token' => '',
		'mailchimp_list_id' => '',
		'accept_expiry_days' => '30',
		'print_codes_in_header' => false,
		'services_default_disabled' => false,

	];
	private $notice_themes = [
		'dark' => [
			'message_color' => '#FFF',
			'accept_button_bg_color' => '#0091FF',
			'notice_bg_color' => '#222',
			'accept_button_color' => '#FFF', 
			'link_color' => '#0091FF',
			'border_color' => 'transparent', 
			'link_hover_color' => '#55c8ff',
			'privacy_button_color' => '#FFF', 
			'privacy_button_bg_color' => '#9e0303',
		],
		'light' => [
			'message_color' => '#000',
			'accept_button_bg_color' => '#0091EE',
			'notice_bg_color' => '#fff',
			'link_color' => '#0091FF',
			'accept_button_color' => '#ffffff', 
			'border_color' => '#eee',
			'link_hover_color' => '#00c8ff',
			'privacy_button_color' => '#FFF', 
			'privacy_button_bg_color' => '#e96363',
		]
	];
	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $gdpr_tools       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $gdpr_tools, $version, $settings ) {

		$this->gdpr_tools = $gdpr_tools;
		$this->version = $version;
		$this->settings = $settings;
	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles( $page ) {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Gdpr_tools_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Gdpr_tools_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		if ($page != $this->page_suffix /*&& $page != 'user-edit.php'*/ ){
			return;
		}
		wp_enqueue_style( $this->gdpr_tools.'-spectrum', plugin_dir_url( __FILE__ ) . 'css/spectrum.css', array(), $this->version, 'all' );
		wp_enqueue_style( $this->gdpr_tools.'-jquery-ui', '//code.jquery.com/ui/1.12.1/themes/base/jquery-ui.css', array(), $this->version, 'all' );
		wp_enqueue_style( $this->gdpr_tools.'-jquery-cookie-consent', plugin_dir_url( __FILE__ ) . '../includes/libs/jquery.eu-cookie-consent/css/eu-cookie-consent.css', array(), $this->version, 'all' );
		wp_enqueue_style( $this->gdpr_tools.'-admin', plugin_dir_url( __FILE__ ) . 'css/gdpr-tools-admin.css', array(), $this->version, 'all' );
	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts( $page ) {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Gdpr_tools_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Gdpr_tools_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		if ($page != $this->page_suffix){
			return;
		}
		wp_enqueue_script( $this->gdpr_tools.'-jquery-ui', 'https://code.jquery.com/ui/1.12.1/jquery-ui.js', array( 'jquery' ), $this->version, true );
		wp_enqueue_script( $this->gdpr_tools.'-spectrum', plugin_dir_url( __FILE__ ) . 'js/spectrum.js', array( 'jquery' ), $this->version, true );
		wp_enqueue_script( $this->gdpr_tools.'-vue', plugin_dir_url( __FILE__ ) . 'js/vue.js', array( 'jquery' ), $this->version, true );
		wp_enqueue_script( $this->gdpr_tools.'-jquery-cookie-consent', plugin_dir_url( __FILE__ ) . '../includes/libs/jquery.eu-cookie-consent/jquery.eu-cookie-consent.js', array( 'jquery' ), $this->version, true );
		
		wp_register_script( $this->gdpr_tools.'-admin', plugin_dir_url( __FILE__ ) . 'js/gdpr-tools-admin.js', array( $this->gdpr_tools. '-vue' ), $this->version, true );
		wp_localize_script($this->gdpr_tools.'-admin', 'GDPR_TOOLS', [ 'ajax_url' => admin_url('admin-ajax.php'), 'notice_themes' => $this->notice_themes ] );
		wp_enqueue_script( $this->gdpr_tools.'-admin' );

		

	}
	public function admin_menu() {
		$this->page_suffix = add_menu_page(
			'GDPR Tools',
			'GDPR Tools',
			'manage_options',
			'gdpr-tools-settings',
			array( $this, 'settings_page' ),
			'dashicons-admin-tools',
			11
		);
	}
	public function admin_init() {
		register_setting( 'gdpr_tools_settings', 'gdpr_tools_settings');
	}
	public function settings_page(){
		$settings = get_option('gdpr-tools-settings');
		foreach ($this->default_settings as $k => $v ){
			if (!isset($settings[$k])){
				$settings[$k] = $v;
			}
			$settings[$k] = stripslashes_deep($settings[$k]);
		}

		$logs = get_option('gdpr-tools-logs');
		if ($logs){
			foreach ($logs as $i => $log ){
				foreach ($log as $k => $v ){
					if ( 'user_id' == $k){
						$logs[$i][$k] = '<a href="'.get_edit_user_link( $v ).'" target="_blank">'.$v.'</a>';
					}
				}
			}
			$logs = array_reverse( $logs );
		}
		include_once( 'partials/gdpr-tools-admin-settings-page.php' );
	}
	public function save_settings() {
		if (isset($_POST['settings'])){
			foreach ($_POST['settings'] as $k => $setting){
				if ($setting == 'true'){
					$_POST['settings'][$k] = true;
				}
				if ($setting == 'false'){
					$_POST['settings'][$k] = false;
				}
			}
			update_option('gdpr-tools-settings', $_POST['settings'] );
		}
		die('1');
	}
	public function remove_logs() {
		update_option('gdpr-tools-logs', [] );
		die('1');
	}
	public function edit_user_profile( $user ){
		if ($this->settings && $this->settings['enable_user_info_removal'] ) {
			$notice_shown = get_user_meta($user->ID, 'gdpr_notice_shown', true );
			$privacy_settings = get_user_meta($user->ID, 'gdpr_privacy', true );
		}

		?>
		<script>
			function gdprt_remove_user_info( form ) {
				form.find('input[name="action"]').val('gdpr_remove_user_info');
				form.find('input[type="submit"]').trigger('click');
			}
		</script>
		<h2>GDPR Tools</h2>
		<table class="form-table">
			<tbody>	
				<tr>
					<th>Remove user data</th><td><input type="button" class="button" value="Remove user info" onclick="gdprt_remove_user_info( jQuery(this).closest('form') )"/></td>
				</tr>
				<tr>
					<th>GDPR consent accepted</th><td><input type="checkbox" name="gdpr_notice_shown" disabled="disabled" value="1" <?php checked( $notice_shown, true ); ?> /><a href="https://wpbomb.com/gdpr-tools-pro/" target="_blank" ><img class="pro-feature" src="<?php echo plugin_dir_url( __FILE__ ); ?>img/pro-feature.png" /></a></td>
				</tr>
				<tr>
					<th colspan="2">User privacy settings</th>
				</tr>
				<?php if ($this->settings['privacy_services']): ?>
					<?php foreach ($this->settings['privacy_services'] as $service ) :?>
						<?php 
						$enabled = true;
						if ($privacy_settings && isset($privacy_settings[$service['slug']]) && -1 == $privacy_settings[$service['slug']]){
							$enabled = false;
						} 
						if (!$privacy_settings && $this->settings['services_default_disabled']){
							$enabled = false;
						}?>
						<tr>
							<td><?php echo $service['name'] ?></td>
							<td><input type="checkbox" disabled="disabled" name="gdpr_privacy[<?php echo $service['slug']?>]" value="1" <?php checked( $enabled, true ); ?> /></td>
						</tr>
					<?php endforeach; ?>
				<?php endif; ?>
			</tbody>
		</table>
		<?php
	}
	public function update_profile_fields( $user_id ){
		if ( current_user_can('edit_user', $user_id) ){
			update_user_meta($user_id, 'gdpr_notice_shown', $_POST['gdpr_notice_shown']);
			$privacy_settings = $_POST['gdpr_privacy'];
			$settings = [];
			foreach ($this->settings['privacy_services'] as $service ) {
				$value = 1;
				if (!isset($privacy_settings[$service['slug']])){
					$value = -1;
				} 
				$settings[$service['slug']] = $value;
			}
			update_user_meta($user_id, 'gdpr_privacy', $settings);
		}
	}
	public function save_user_profile(){
		if ($this->settings && $this->settings['enable_user_info_removal'] && isset($_POST['action']) && 'gdpr_remove_user_info' == $_POST['action'] ) {
			Gdpr_tools_helper::remove_user_data($_POST['user_id'], $this->settings);
			$redirect = add_query_arg( 'updated', true, get_edit_user_link( $_POST['user_id'] ) );
			wp_redirect($redirect);
			exit;
		}
	}

}
