(function( $ ) {
	'use strict';





Vue.config.debug = true;
var bus = new Vue();
Vue.component('color-picker', {
  template: '<input/>',
  props: ['field'],
  mounted: function() {
    let self = this;
    var spectrum = $(this.$el).spectrum({
     change: function(color) {
      bus.$emit('update-color', color.toHexString(), self.field);   
    }
  });
    bus.$on('update-color-spectrum-'+ self.field, function (color) {
     spectrum.spectrum("set", color);
     jQuery('#'+self.field).val(color);
   });
    spectrum.spectrum("set", jQuery('#'+self.field).val());
  },
  beforeDestroy: function() {
  }
});
Vue.component('widget', {
  created: function() { 
   let self = this;
   bus.$on('update-color', function (color, field) {
     self.settings[field] = color;
   });
   jQuery('#custom-css').html(this.settings.custom_css);   
 },
 data () { 

   if (jQuery('#gdpr-tools-data-settings').html()){
    return {
      settings: JSON.parse(jQuery('#gdpr-tools-data-settings').html()),
      logs: JSON.parse(jQuery('#gdpr-tools-data-logs').html())
    };
  }else{
   return {};
 }
},
mounted: function() {
  let self = this;
  $( "#gdpr-tools-settings" ).tabs({  
    activate: function(event, ui) {             
      var pos = $(window).scrollTop();
      window.location.hash = ui.newTab.find('a').attr('href');   
      $(window).scrollTop(pos);
    }
  });
  $( "#privacy-services table tbody" ).sortable({
   start: function(event, ui) {
    ui.item.startPos = ui.item.index();
  },
  stop: function(event, ui) {
    //swap elements
    var _tmp = self.settings.privacy_services[ui.item.startPos];
    self.settings.privacy_services[ui.item.startPos] = self.settings.privacy_services[ui.item.index()];
    self.settings.privacy_services[ui.item.index()] = _tmp;
  }
});
  $( "#privacy-services table tbody" ).disableSelection();

},

watch: {
  'settings.enable_cookie_notice': function(val, oldVal){
  },
  'settings.notice_theme': function(val, oldVal){
    if ( 'custom' == val ){
      return;
    }
    for ( var a in GDPR_TOOLS.notice_themes[ val ]){
      this.settings[a] =  GDPR_TOOLS.notice_themes[ val ][a];
      this.update_misc_styles();
    }
  },
  'settings.notice_position': function(val, oldVal){
    this.set_custom_theme();
    this.update_notice();
  },
  'settings.notice_message': function(val, oldVal){
   this.set_custom_theme();
   this.update_notice();
 },
 'settings.notice_accept_button_text': function(val, oldVal){
   this.set_custom_theme();
   this.update_notice();
 },
 'settings.notice_bg_color': function(val, oldVal){
   this.set_custom_theme();
   this.update_misc_styles();

 },
 'settings.message_color': function(val, oldVal){
   this.set_custom_theme();
   this.update_misc_styles();
 },
 'settings.link_color': function(val, oldVal){
   this.set_custom_theme();
   this.update_misc_styles();
 },
 'settings.link_hover_color': function(val, oldVal){
   this.set_custom_theme();
   this.update_misc_styles();
 },
 'settings.accept_button_bg_color': function(val, oldVal){
   this.set_custom_theme();
   this.update_misc_styles();
 },
 'settings.accept_button_color': function(val, oldVal){
   this.set_custom_theme();
   this.update_misc_styles();
 },
 'settings.border_color': function(val, oldVal){
   this.set_custom_theme();
   this.update_misc_styles();
 },
 'settings.enable_privacy_settings': function(val, oldVal){
   this.set_custom_theme();
   this.update_notice();
 },
 'settings.privacy_btn_text': function(val, oldVal){
   this.set_custom_theme();
   this.update_notice();
 },
 'settings.custom_css': function(val, oldVal){
   jQuery('#custom-css').html(val); 
   this.update_notice();
 },
 'settings.privacy_button_bg_color': function(val, oldVal){
   this.set_custom_theme();
   this.update_misc_styles();
 },
 'settings.privacy_button_color': function(val, oldVal){
   this.set_custom_theme();
   this.update_misc_styles();
 }

},
methods: {
  submit: function(){
   gdprt_spin();
   $.ajax({
    type: "POST",
    url: GDPR_TOOLS.ajax_url,
    data: {
      action: 'gdpr_tools_save_settings',
      settings: this.settings 
    },
    success: function (response) {
     gdprt_unspin();
     gdprt_show_notification('Settings were updated.');
   },

 });
 },
 remove_logs: function(){
   gdprt_spin();
   $.ajax({
    type: "POST",
    url: GDPR_TOOLS.ajax_url,
    data: {
      action: 'gdpr_tools_remove_logs',
      settings: this.settings 
    },
    success: function (response) {
     gdprt_unspin();
     gdprt_show_notification('Logs were removed.');
   },

 });
 },
 set_custom_theme: function (){
  this.settings.notice_theme = 'custom';
},
update_notice: function (){
  let self = this;
  $('.GDPR-tools-consent').remove();
  $.EUCookie({
    'designMode' : true,
    'acceptBtn' : self.settings.notice_accept_button_text,
    'message': self.settings.notice_message,
    'position': self.settings.notice_position,
    'links' : {
      'link_1' : '/cookie-policy',
      'link_1_text' : 'our cookie policy'
    },
    'privacyBtnEnable' : self.settings.enable_privacy_settings,
    'privacyBtnText' : self.settings.privacy_btn_text
  }).init();

},
update_misc_styles: function(){
 let self = this;
 jQuery('#misc-styles').html(
  ".GDPR-tools-consent { background: "+self.settings.notice_bg_color+"; color: "+self.settings.message_color+"; border: 1px solid "+self.settings.border_color+";  } " +
  ".GDPR-tools-consent__message a, .GDPR-tools-consent__message a:visited{ color: "+self.settings.link_color+";  }" + 
  ".GDPR-tools-consent .GDPR-tools-consent__btn, .GDPR-tools-consent .GDPR-tools-consent__btn:visited{   background: "+self.settings.accept_button_bg_color+"; color: "+self.settings.accept_button_color+"; } " +
  ".GDPR-tools-consent__message a:hover{ color: "+self.settings.link_hover_color+";  }" +
  ".GDPR-tools-consent .GDPR-tools-consent__btn.privacy, .GDPR-tools-consent .GDPR-tools-consent__btn.privacy:visited{   background: "+self.settings.privacy_button_bg_color+"; color: "+self.settings.privacy_button_color+"; } "
  );
 self.update_notice();
},
string_to_slug: function (str) {
    str = str.replace(/^\s+|\s+$/g, ''); // trim
    str = str.toLowerCase();

    // remove accents, swap ñ for n, etc
    var from = "àáäâèéëêìíïîòóöôùúüûñç·/_,:;";
    var to   = "aaaaeeeeiiiioooouuuunc------";
    for (var i=0, l=from.length ; i<l ; i++) {
      str = str.replace(new RegExp(from.charAt(i), 'g'), to.charAt(i));
    }

    str = str.replace(/[^a-z0-9 -]/g, '') // remove invalid chars
        .replace(/\s+/g, '-') // collapse whitespace and replace by -
        .replace(/-+/g, '-'); // collapse dashes

        return str;
      }

    }
  });


new Vue({
  el: '#gdpr-tools-settings',

});
function gdprt_spin(){
  jQuery('.sc-loader').show();
}

function gdprt_unspin(){
  jQuery('.sc-loader').hide();
}

function gdprt_show_notification( text ){
  $( "#gdpr-notification" ).remove();
  $('<div id="gdpr-notification"><p>' + text + '</p></div>').appendTo('body');
  $( "#gdpr-notification" ).dialog({
   close: function( event, ui ) {
     $( "#gdpr-notification" ).remove();
   },
   buttons: [
   {
    text: "Ok",
    click: function() {
      $( this ).dialog( "close" );
    }
      // Uncommenting the following line would hide the text,
      // resulting in the label being used as a tooltip
      //showText: false
    }
    ]
  });
}
})( jQuery );
