<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://wpbomb.com/gdpr-tools/
 * @since             1.0.0
 * @package           Gdpr_tools
 *
 * @wordpress-plugin
 * Plugin Name:       GDPR Tools
 * Plugin URI:        https://wpbomb.com/gdpr-tools/
 * Description:       This plugin helps WP administrators to consent GDPR 
 * Version:           1.0.2
 * Author:            Vladimir Radnaev
 * Author URI:        https://wpbomb.com/
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       gdpr-tools
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'GDPR_TOOLS_VERSION', '1.0.2' );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-gdpr-tools-activator.php
 */
function activate_gdpr_tools() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-gdpr-tools-activator.php';
	Gdpr_tools_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-gdpr-tools-deactivator.php
 */
function deactivate_gdpr_tools() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-gdpr-tools-deactivator.php';
	Gdpr_tools_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_gdpr_tools' );
register_deactivation_hook( __FILE__, 'deactivate_gdpr_tools' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-gdpr-tools.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_gdpr_tools() {

	$plugin = new Gdpr_tools();
	$plugin->run();

}
add_filter( 'plugin_row_meta', function ( $links, $file ) {    
    if ( plugin_basename( __FILE__ ) == $file ) {
        $row_meta = array(
          'settings'    => '<a href="' .esc_url( get_admin_url(null, 'options-general.php?page=gdpr-tools-settings') ). '" target="_blank" aria-label="' . esc_attr__( 'Plugin Additional Links', 'gdpr-tools' ) . '" >' . esc_html__( 'Settings', 'gdpr-tools' ) . '</a>',
          'docs'    => '<a href="' . esc_url( 'https://wpbomb.com/gdpr-tools/' ) . '" target="_blank" aria-label="' . esc_attr__( 'Plugin Additional Links', 'gdpr-tools' ) . '" style="color:green;">' . esc_html__( 'Docs', 'gdpr-tools' ) . '</a>',
          'pro-version'    => '<a href="' . esc_url( 'https://wpbomb.com/gdpr-tools-pro/' ) . '" target="_blank" aria-label="' . esc_attr__( 'Plugin Additional Links', 'gdpr-tools' ) . '" style="color:red; font-weight: 800;">' . esc_html__( 'PRO version', 'gdpr-tools' ) . '</a>'
        );
        return array_merge( $links, $row_meta );
    }
    return (array) $links;
}, 10, 2 );

run_gdpr_tools();
