<?php

/**
 * The file that defines the helper plugin class
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * @link       http://example.com
 * @since      1.0.0
 *
 * @package    Gdpr_tools
 * @subpackage Gdpr_tools/includes
 */

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @package    Gdpr_tools
 * @subpackage Gdpr_tools/includes
 * @author     Your Name <email@example.com>
 */
use \DrewM\MailChimp\MailChimp;
class Gdpr_tools_helper {
	private static $remove_fields = [
		[ 'action' => 'remove', 'search' => 'regexp', 'name' => '/^billing_(?:.*)/' ],
		[ 'action' => 'remove', 'search' => 'regexp', 'name' => '/^shipping_(?:.*)/' ],
		[ 'action' => 'rename', 'search' => '=', 'name' => 'first_name' ],
		[ 'action' => 'rename', 'search' => '=', 'name' => 'last_name' ],
		[ 'action' => 'rename', 'search' => '=', 'name' => 'nickname' ]
	];

	public static function remove_user_data( $user_id = null, $settings ){
		if ( !$user_id ){
			$user_id = get_current_user_id();
		}
		$data = get_user_meta( $user_id );
		$renamed_value = uniqid('deleted_');
		foreach ($data as $k => $v ){
			foreach (self::$remove_fields as $remove_field ){
				if ( '=' == $remove_field['search']){
					if ($remove_field['name'] == $k ){
						if ('remove' == $remove_field['action']){
							delete_user_meta( $user_id, $k );
						}elseif ('rename' == $remove_field['action']){
							update_user_meta( $user_id, $k, $renamed_value );
						}
					}
				}elseif ( 'regexp' == $remove_field['search']){
					if (preg_match( $remove_field['name'],  $k )){
						if ('remove' == $remove_field['action']){
							delete_user_meta( $user_id, $k );
						}elseif ('rename' == $remove_field['action']){
							update_user_meta( $user_id, $k, $renamed_value );
						}

					}
				}
			}
		}
		//remove userdata
		$userdata = get_userdata( $user_id );
		if ( $settings['remove_mailchimp_email'] && $settings['mailchimp_api_token'] && $settings['mailchimp_list_id'] ){
			require_once(plugin_dir_path( dirname( __FILE__ ) ).'includes/libs/mailchimp/autoload.php');
			$email = $userdata->user_email;
			$api_key =  $settings['mailchimp_api_token'];
			$list_id = $settings['mailchimp_list_id'];
			$MailChimp = new MailChimp($api_key);
			$subscriber_hash = $MailChimp->subscriberHash($email);
			$res = $MailChimp->delete("lists/$list_id/members/$subscriber_hash"); 
		}

		wp_update_user( array( 'ID' => $user_id, /*'user_login' => $renamed_value, 'user_pass' => $renamed_value, */ 'user_email' => $renamed_value.'@example.com', 'display_name' => $renamed_value, 'user_url' => $renamed_value, 'user_registered' => date('Y-m-d H:i:s') ) );
		//log
		$logs = get_option('gdpr-tools-logs');
		$logs[] = ['date' => date('Y-m-d H:i:s', current_time( 'timestamp' )), 'user_id' => $user_id, 'event' => 'remove_user_info', 'notes' => 'User data has been deleted.' ];
		update_option( 'gdpr-tools-logs', array_slice($logs, -50, 50 ) );
	}

}
