(function( $ ) {
	'use strict';

	/**
	 * All of the code for your public-facing JavaScript source
	 * should reside in this file.
	 *
	 * Note: It has been assumed you will write jQuery code here, so the
	 * $ function reference has been prepared for usage within the scope
	 * of this function.
	 *
	 * This enables you to define handlers, for when the DOM is ready:
	 *
	 * $(function() {
	 *
	 * });
	 *
	 * When the window is loaded:
	 *
	 * $( window ).load(function() {
	 *
	 * });
	 *
	 * ...and/or other possibilities.
	 *
	 * Ideally, it is not considered best practise to attach more than a
	 * single DOM-ready or window-load handler for a particular page.
	 * Although scripts in the WordPress core, Plugins and Themes may be
	 * practising this, we should strive to set a better example in our own work.
	 */

	})( jQuery );


	(function() {

		function ConfirmBox( opts ) {
			this.wrapper = opts.wrapper;
			this.confirm_callback = opts.confirm_callback;
			this.cancel_callback = opts.cancel_callback;
			this.settings = null;
			this.init();
		}

		ConfirmBox.prototype = {
			init: function() {
				this.instance = null;
				this.create();
				this.layout();
				this.actions();
			},
			create: function() {
				this.instance = document.getElementById( this.wrapper );

			},
			layout: function() {
				var wrapper = this.instance;
				var winHeight = window.innerHeight || document.documentElement.clientHeight || document.body.clientHeight;

				wrapper.style.height = winHeight + "px";	
			},
			show: function(element) {
				//var element = this.instance;
				element.style.display = "block";
				element.style.opacity = 1;
			},
			hide: function() {
				var element = this.instance;
				element.style.opacity = 0;
				setTimeout(function() {
					element.style.display = "none";
				}, 1000);
			},
			actions: function() {
				var self = this;
				self.instance.querySelector( "#confirm-ok" ).
				addEventListener( "click", function() {
					self.confirm_callback();
					self.hide( self.instance );
				}, false);

				self.instance.querySelector( "#confirm-cancel" ).
				addEventListener( "click", function() {
					self.cancel_callback();
					self.hide( self.instance );
				}, false);
			}
		};

		window.ConfirmBox = ConfirmBox;
	})();

