<?php

/**
 * The public-facing functionality of the plugin.
 *
 * @link       http://example.com
 * @since      1.0.0
 *
 * @package    Gdpr_tools
 * @subpackage Gdpr_tools/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Gdpr_tools
 * @subpackage Gdpr_tools/public
 * @author     Your Name <email@example.com>
 */

class Gdpr_tools_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $gdpr_tools    The ID of this plugin.
	 */
	private $gdpr_tools;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;
	private $settings;
	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $gdpr_tools       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */

	
	public function __construct( $gdpr_tools, $version, $settings ) {

		$this->gdpr_tools = $gdpr_tools;
		$this->version = $version;
		$this->settings = $settings;

	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Gdpr_tools_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Gdpr_tools_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		if ($this->settings && $this->settings['enable_cookie_notice'] || $this->settings && $this->settings['trigger_privacy_modal_class']){
			wp_enqueue_style( $this->gdpr_tools.'-jquery-cookie-consent', plugin_dir_url( __FILE__ ) . '../includes/libs/jquery.eu-cookie-consent/css/eu-cookie-consent.css', array(), $this->version, 'all' );
			wp_enqueue_style( $this->gdpr_tools.'-modalbox', plugin_dir_url( __FILE__ ) . '../includes/libs/modalbox/modalbox.css', array(), $this->version, 'all' );
			wp_enqueue_style( $this->gdpr_tools.'-switcher', plugin_dir_url( __FILE__ ) . '../includes/libs/jquery.switcher/switcher.min.css', array(), $this->version, 'all' );
		}
		wp_enqueue_style( $this->gdpr_tools, plugin_dir_url( __FILE__ ) . 'css/gdpr-tools-public.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Gdpr_tools_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Gdpr_tools_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		if ($this->settings && $this->settings['enable_cookie_notice'] || $this->settings && $this->settings['trigger_privacy_modal_class']){
			wp_enqueue_script( $this->gdpr_tools.'-jquery-cookie-consent', plugin_dir_url( __FILE__ ) . '../includes/libs/jquery.eu-cookie-consent/jquery.eu-cookie-consent.js', array( 'jquery' ), $this->version, true );
			wp_enqueue_script( $this->gdpr_tools.'-modalbox', plugin_dir_url( __FILE__ ) . '../includes/libs/modalbox/modalbox.js', array( 'jquery' ), $this->version, true );
			wp_enqueue_script( $this->gdpr_tools.'-switcher', plugin_dir_url( __FILE__ ) . '../includes/libs/jquery.switcher/switcher.min.js', array( 'jquery' ), $this->version, true );
			
		}
		wp_register_script( $this->gdpr_tools, plugin_dir_url( __FILE__ ) . 'js/gdpr-tools-public.js', array( 'jquery' ), $this->version, true );
		wp_localize_script($this->gdpr_tools, 'GDPR_TOOLS', [ 'ajax_url' => admin_url('admin-ajax.php'), 'is_logged' => is_user_logged_in() ] );
		wp_enqueue_script( $this->gdpr_tools );
	}
	public function print_codes(){
		if ($this->settings && $this->settings['privacy_services']){
		$privacy_settings = [];
		if (isset( $_COOKIE['gdpr_privacy'] )){
			$privacy_settings = json_decode(stripslashes_deep($_COOKIE['gdpr_privacy']),true);
		}
		if ( is_user_logged_in() ){ 
			$privacy_settings = get_user_meta(get_current_user_id(), 'gdpr_privacy', true );
		}
		foreach ($this->settings['privacy_services'] as $service ) {
			if ($privacy_settings && isset($privacy_settings[$service['slug']]) && -1 == $privacy_settings[$service['slug']]){
				continue;
			} 
			if (!$privacy_settings && $this->settings['services_default_disabled']){
				continue;
			}
				?>
			<!-- start code gdpr-tools <?php echo $service['slug'] ?> -->
			<?php echo do_shortcode( stripslashes_deep($service['code']) ); ?>
			<!-- end code gdpr-tools <?php echo $service['slug'] ?> -->
			<?php }
		}
	}
	public function footer() {
		if ($this->settings && $this->settings['enable_cookie_notice']){
			?>
			<div id="gdpr-confirm-wrapper">
				<div id="confirm-box"><h2 id="confirm-header">Privacy Policy Settings</h2>
					<div id="confirm-content">
						<table >
							<tbody>
								<?php if ($this->settings['privacy_services']): ?>
									<?php foreach ($this->settings['privacy_services'] as $service ) :?>
										<tr data-slug="<?php echo $service['slug'] ?>">
											<td><?php echo $service['name'] ?></td>
											<td><?php echo $service['use_reason'] ?></td>
											<td class="flex"><input type="checkbox" name="<?php echo $service['slug']?>" class="service-switch"></td>
										</tr>
									<?php endforeach; ?>
								<?php endif; ?>
							</tbody>
						</table>
					</div>
					<div id="confirm-buttons"><button id="confirm-ok">SAVE</button><button type="button" id="confirm-cancel">Cancel</button></div>
				</div>
			</div>
			<?php
			$settings = $this->settings;
			//disable notice for users who has accepted notice already
			if ( is_user_logged_in() ){
				$notice_shown_meta = get_user_meta(get_current_user_id(), 'gdpr_notice_shown', true );
				//var_dump($notice_shown_meta);die();
				if ($notice_shown_meta === '1'){
					$notice_shown = true;
				}else{
					$notice_shown = false;
				}
			}else{
				if (isset($_COOKIE['gdpr_notice_shown']) && 1 == $_COOKIE['gdpr_notice_shown'] ){
					$notice_shown = true;
				}else{
					$notice_shown = false;
				}
			}
			if ($notice_shown){
				$settings['enable_cookie_notice'] = false;
			}
			?>
			<script id="gdpr-tools-data-settings" type="application/json"><?php echo json_encode( array_map( function($e){ return stripslashes_deep($e); }, $settings)); ?></script>
			<?php
		}
	
			if ( $this->settings && $this->settings['trigger_privacy_modal_class'] ){
				?>
				<script>
					jQuery(function() {
						jQuery(document).on('click', '.trigger_privacy_modal_class', function(){
							confBox.show(confBox.instance);
						} );
					});
				</script>
				<?php
			}

		}

		public function init() {
			if ( is_user_logged_in() ){
				$privacy_settings_meta = get_user_meta(get_current_user_id(), 'gdpr_privacy', true );
				if ($privacy_settings_meta ){
					setcookie("gdpr_privacy", json_encode( $privacy_settings_meta ));
				}

				//maybe remove user info
				if ($this->settings && $this->settings['enable_user_info_removal'] && isset($_GET['gdprt-remove-user-info'])){
					Gdpr_tools_helper::remove_user_data(get_current_user_id(), $this->settings);
				}
				
			}
		}
		public function header() {
			if ($this->settings && $this->settings['enable_cookie_notice'] || $this->settings && $this->settings['trigger_privacy_modal_class']){

				$styles = ''; 
				if ( $this->settings['custom_css'] ){
					$styles .=  $this->settings['custom_css']."\n";
				}
				$styles .= sprintf(
					".GDPR-tools-consent { background: %s; color: %s; border: 1px solid %s;  } \n" .
					".GDPR-tools-consent__message a, .GDPR-tools-consent__message a:visited{ color: %s;  }" .
					".GDPR-tools-consent .GDPR-tools-consent__btn, .GDPR-tools-consent .GDPR-tools-consent__btn:visited{   background: %s; color: %s; }" .
					".GDPR-tools-consent__message a:hover{ color: %s;  }" .
					".GDPR-tools-consent .GDPR-tools-consent__btn.privacy, .GDPR-tools-consent .GDPR-tools-consent__btn.privacy:visited{   background: %s; color: %s; } ", $this->settings['notice_bg_color'], $this->settings['message_color'], $this->settings['border_color'], $this->settings['link_color'], $this->settings['accept_button_bg_color'], $this->settings['accept_button_color'], $this->settings['link_hover_color'], $this->settings['privacy_button_bg_color'], $this->settings['privacy_button_color']
				);
				echo "<style id=\"gdpr-tools-styles\">\n" . $styles . "</style>\n";
			}

		}
		public function save_privacy_settings(){
			$settings = $_POST['settings'];
			update_user_meta(get_current_user_id(), 'gdpr_privacy', $settings );
		}
		public function wp_login( $user_login, $user ){
			//check if user already accepted notice in another browser session
			$notice_shown = get_user_meta(get_current_user_id(), 'gdpr_notice_shown', true );
			if (!$notice_shown && isset($_COOKIE['gdpr_notice_shown']) && 1 == $_COOKIE['gdpr_notice_shown'] ){
				update_user_meta(get_current_user_id(), 'gdpr_notice_shown', 1 );
			}
		}
		public function save_notice_shown(){
			update_user_meta(get_current_user_id(), 'gdpr_notice_shown', 1 );
			die('1');
		}
		
	}
